@@ -1,20 +1,12 @@
 import re
 
-import requests
-
-VHOST_DB_PATH = '/home/s/st/staff/vhost/vhost-app.conf'
-VHOST_DB_URL = 'https://www.ocf.berkeley.edu/~staff/vhost-app.conf'
+VHOST_DB_PATH = '/etc/ocf/vhost-app.conf'
 
 
 def get_app_vhost_db():
-    """Returns lines from the application vhost database. Loaded from the
-    filesystem (if available), or from the web if not."""
-    try:
-        with open(VHOST_DB_PATH) as f:
-            return f.read().splitlines()
-    except IOError:
-        # fallback to database loaded from web
-        return requests.get(VHOST_DB_URL, timeout=20).text.split('\n')
+    """Returns lines from the application vhost config file."""
+    with open(VHOST_DB_PATH) as f:
+        return f.read().splitlines()
 
 
 def get_app_vhosts():
